@@ -62,6 +62,7 @@ conf_t *conf_load( int argc, char *argv[] )
 	conf->ping_interval = 180;
 	conf->ping_timeout = 300;
 	conf->user = NULL;
+	conf->protocols = NULL;
 	proxytype = 0;
 	
 	i = conf_loadini( conf, global.conf_file );
@@ -77,7 +78,7 @@ conf_t *conf_load( int argc, char *argv[] )
 		   at a *valid* configuration file. */
 	}
 	
-	while( argc > 0 && ( opt = getopt( argc, argv, "i:p:P:nvIDFc:d:hR:u:" ) ) >= 0 )
+	while( argc > 0 && ( opt = getopt( argc, argv, "i:p:P:nvIDFc:d:hR:u:V" ) ) >= 0 )
 	/*     ^^^^ Just to make sure we skip this step from the REHASH handler. */
 	{
 		if( opt == 'i' )
@@ -126,7 +127,7 @@ conf_t *conf_load( int argc, char *argv[] )
 		else if( opt == 'h' )
 		{
 			printf( "Usage: bitlbee [-D/-F [-i <interface>] [-p <port>] [-n] [-v]] [-I]\n"
-			        "               [-c <file>] [-d <dir>] [-h]\n"
+			        "               [-c <file>] [-d <dir>] [-x] [-h]\n"
 			        "\n"
 			        "An IRC-to-other-chat-networks gateway\n"
 			        "\n"
@@ -142,7 +143,15 @@ conf_t *conf_load( int argc, char *argv[] )
 			        "  -v  Be verbose (only works in combination with -n)\n"
 			        "  -c  Load alternative configuration file\n"
 			        "  -d  Specify alternative user configuration directory\n"
-			        "  -h  Show this help page.\n" );
+			        "  -x  Command-line interface to password encryption/hashing\n"
+			        "  -h  Show this help page.\n"
+			        "  -V  Show version info.\n" );
+			return NULL;
+		}
+		else if( opt == 'V' )
+		{
+			printf( "BitlBee %s\nAPI version %06x\n",
+			        BITLBEE_VERSION, BITLBEE_VERSION_CODE );
 			return NULL;
 		}
 		else if( opt == 'R' )
@@ -305,6 +314,11 @@ static int conf_loadini( conf_t *conf, char *file )
 				g_free( conf->user );
 				conf->user = g_strdup( ini->value );
 			}
+			else if( g_strcasecmp( ini->key, "protocols" ) == 0 )
+			{
+				g_strfreev( conf->protocols );
+				conf->protocols = g_strsplit_set( ini->value, " \t,;", -1 );
+			}
 			else
 			{
 				fprintf( stderr, "Error: Unknown setting `%s` in configuration file (line %d).\n", ini->key, ini->line );
