@@ -153,11 +153,11 @@ static const htmlentity_t ent[] =
 void strip_html( char *in )
 {
 	char *start = in;
-	char *out = g_malloc( strlen( in ) + 1 );
+	char out[strlen(in)+1];
 	char *s = out, *cs;
 	int i, matched;
 	
-	memset( out, 0, strlen( in ) + 1 );
+	memset( out, 0, sizeof( out ) );
 	
 	while( *in )
 	{
@@ -219,7 +219,6 @@ void strip_html( char *in )
 	}
 	
 	strcpy( start, out );
-	g_free( out );
 }
 
 char *escape_html( const char *html )
