@@ -42,6 +42,7 @@ G_MODULE_EXPORT char *add_cr( char *text );
 G_MODULE_EXPORT char *strip_newlines(char *source);
 
 G_MODULE_EXPORT time_t get_time( int year, int month, int day, int hour, int min, int sec );
+G_MODULE_EXPORT time_t mktime_utc( struct tm *tp );
 double gettime( void );
 
 G_MODULE_EXPORT void strip_html( char *msg );
@@ -61,7 +62,7 @@ G_MODULE_EXPORT int bool2int( char *value );
 
 G_MODULE_EXPORT struct ns_srv_reply *srv_lookup( char *service, char *protocol, char *domain );
 
-G_MODULE_EXPORT char *word_wrap( char *msg, int line_len );
+G_MODULE_EXPORT char *word_wrap( const char *msg, int line_len );
 
 G_MODULE_EXPORT gboolean ssl_sockerr_again( void *ssl );
 
