@@ -30,6 +30,7 @@
  */
 #define TYPING_NOTIFICATION_MESSAGE "\r\r\rBEWARE, ME R TYPINK MESSAGE!!!!\r\r\r"
 #define GROUPCHAT_SWITCHBOARD_MESSAGE "\r\r\rME WANT TALK TO MANY PEOPLE\r\r\r"
+#define SB_KEEPALIVE_MESSAGE "\r\r\rDONT HANG UP ON ME!\r\r\r"
 
 #ifdef DEBUG_MSN
 #define debug( text... ) imcb_log( ic, text );
@@ -53,6 +54,10 @@
                            "TypingUser: %s\r\n" \
                            "\r\n\r\n"
 
+#define SB_KEEPALIVE_HEADERS "MIME-Version: 1.0\r\n" \
+                             "Content-Type: text/x-ping\r\n" \
+                             "\r\n\r\n"
+
 #define PROFILE_URL "http://members.msn.com/"
 
 struct msn_data
@@ -82,6 +87,7 @@ struct msn_switchboard
 	int fd;
 	gint inp;
 	struct msn_handler_data *handler;
+	gint keepalive;
 	
 	int trId;
 	int ready;
@@ -96,7 +102,6 @@ struct msn_switchboard
 
 struct msn_away_state
 {
-	int number;
 	char code[4];
 	char name[16];
 };
@@ -135,7 +140,7 @@ struct msn_handler_data
 #define STATUS_SB_IM_SPARE	4	/* Make one-to-one conversation switchboard available again, invite failed. */
 #define STATUS_SB_CHAT_SPARE	8	/* Same, but also for groupchats (not used yet). */
 
-int msn_chat_id;
+extern int msn_chat_id;
 extern const struct msn_away_state msn_away_state_list[];
 extern const struct msn_status_code msn_status_code_list[];
 
@@ -144,8 +149,8 @@ extern const struct msn_status_code msn_status_code_list[];
    is down already (for example, when an impatient user disabled the
    connection), the callback should check whether it's still listed here
    before doing *anything* else. */
-GSList *msn_connections;
-GSList *msn_switchboards;
+extern GSList *msn_connections;
+extern GSList *msn_switchboards;
 
 /* ns.c */
 gboolean msn_ns_connected( gpointer data, gint source, b_input_condition cond );
@@ -161,6 +166,7 @@ char **msn_linesplit( char *line );
 int msn_handler( struct msn_handler_data *h );
 char *msn_http_encode( const char *input );
 void msn_msgq_purge( struct im_connection *ic, GSList **list );
+gboolean msn_set_display_name( struct im_connection *ic, const char *rawname );
 
 /* tables.c */
 const struct msn_away_state *msn_away_state_by_number( int number );
@@ -179,5 +185,7 @@ struct groupchat *msn_sb_to_chat( struct msn_switchboard *sb );
 void msn_sb_destroy( struct msn_switchboard *sb );
 gboolean msn_sb_connected( gpointer data, gint source, b_input_condition cond );
 int msn_sb_write_msg( struct im_connection *ic, struct msn_message *m );
+void msn_sb_start_keepalives( struct msn_switchboard *sb, gboolean initial );
+void msn_sb_stop_keepalives( struct msn_switchboard *sb );
 
 #endif //_MSN_H
