@@ -41,7 +41,7 @@
 
 struct twitter_xml_list {
 	int type;
-	int next_cursor;
+	gint64 next_cursor;
 	GSList *list;
 	gpointer data;
 };
@@ -58,6 +58,8 @@ struct twitter_xml_status {
 	guint64 id;
 };
 
+static void twitter_groupchat_init(struct im_connection *ic);
+
 /**
  * Frees a twitter_xml_user struct.
  */
@@ -116,20 +118,49 @@ static void twitter_add_buddy(struct im_connection *ic, char *name, const char *
 	}
 }
 
+/* Warning: May return a malloc()ed value, which will be free()d on the next
+   call. Only for short-term use. */
+static char *twitter_parse_error(struct http_request *req)
+{
+	static char *ret = NULL;
+	struct xt_parser *xp = NULL;
+	struct xt_node *node;
+	
+	g_free(ret);
+	ret = NULL;
+	
+	if (req->body_size > 0)
+	{
+		xp = xt_new(NULL, NULL);
+		xt_feed(xp, req->reply_body, req->body_size);
+		
+		if ((node = xt_find_node(xp->root, "hash")) &&
+		    (node = xt_find_node(node->children, "error")) &&
+		    node->text_len > 0)
+		{
+			ret = g_strdup_printf("%s (%s)", req->status_string, node->text);
+			xt_free(xp);
+			return ret;
+		}
+		
+		xt_free(xp);
+	}
+	
+	return req->status_string;
+}
+
 static void twitter_http_get_friends_ids(struct http_request *req);
 
 /**
  * Get the friends ids.
  */
-void twitter_get_friends_ids(struct im_connection *ic, int next_cursor)
+void twitter_get_friends_ids(struct im_connection *ic, gint64 next_cursor)
 {
-	struct twitter_data *td = ic->proto_data;
-
 	// Primitive, but hey! It works...	
 	char* args[2];
 	args[0] = "cursor";
-	args[1] = g_strdup_printf ("%d", next_cursor);
-	twitter_http(TWITTER_FRIENDS_IDS_URL, twitter_http_get_friends_ids, ic, 0, td->user, td->pass, td->oauth_info, args, 2);
+	args[1] = g_strdup_printf ("%lld", (long long) next_cursor);
+	twitter_http(ic, TWITTER_FRIENDS_IDS_URL, twitter_http_get_friends_ids, ic, 0, args, 2);
 
 	g_free(args[1]);
 }
@@ -139,8 +170,12 @@ void twitter_get_friends_ids(struct im_connection *ic, int next_cursor)
  */
 static xt_status twitter_xt_next_cursor( struct xt_node *node, struct twitter_xml_list *txl )
 {
-	// Do something with the cursor.
-	txl->next_cursor = node->text != NULL ? atoi(node->text) : -1;
+	char *end = NULL;
+	
+	if( node->text )
+		txl->next_cursor = g_ascii_strtoll( node->text, &end, 10 );
+	if( end == NULL )
+		txl->next_cursor = -1;
 
 	return XT_HANDLED;
 }
@@ -195,7 +230,7 @@ static void twitter_http_get_friends_ids(struct http_request *req)
 	if (req->status_code != 200) {
 		// It didn't go well, output the error and return.
 		if (++td->http_fails >= 5)
-			imcb_error(ic, "Could not retrieve friends. HTTP STATUS: %d", req->status_code);
+			imcb_error(ic, "Could not retrieve friends: %s", twitter_parse_error(req));
 		
 		return;
 	} else {
@@ -383,19 +418,19 @@ static void twitter_http_get_home_timeline(struct http_request *req);
 /**
  * Get the timeline.
  */
-void twitter_get_home_timeline(struct im_connection *ic, int next_cursor)
+void twitter_get_home_timeline(struct im_connection *ic, gint64 next_cursor)
 {
 	struct twitter_data *td = ic->proto_data;
 
 	char* args[4];
 	args[0] = "cursor";
-	args[1] = g_strdup_printf ("%d", next_cursor);
+	args[1] = g_strdup_printf ("%lld", (long long) next_cursor);
 	if (td->home_timeline_id) {
 		args[2] = "since_id";
 		args[3] = g_strdup_printf ("%llu", (long long unsigned int) td->home_timeline_id);
 	}
 
-	twitter_http(TWITTER_HOME_TIMELINE_URL, twitter_http_get_home_timeline, ic, 0, td->user, td->pass, td->oauth_info, args, td->home_timeline_id ? 4 : 2);
+	twitter_http(ic, TWITTER_HOME_TIMELINE_URL, twitter_http_get_home_timeline, ic, 0, args, td->home_timeline_id ? 4 : 2);
 
 	g_free(args[1]);
 	if (td->home_timeline_id) {
@@ -403,6 +438,19 @@ void twitter_get_home_timeline(struct im_connection *ic, int next_cursor)
 	}
 }
 
+static void twitter_groupchat_init(struct im_connection *ic)
+{
+	char *name_hint;
+	struct groupchat *gc;
+	struct twitter_data *td = ic->proto_data;
+	
+	td->home_timeline_gc = gc = imcb_chat_new( ic, "home/timeline" );
+	
+	name_hint = g_strdup_printf( "Twitter_%s", ic->acc->user );
+	imcb_chat_name_hint( gc, name_hint );
+	g_free( name_hint );
+}
+
 /**
  * Function that is called to see the statuses in a groupchat window.
  */
@@ -415,24 +463,19 @@ static void twitter_groupchat(struct im_connection *ic, GSList *list)
 
 	// Create a new groupchat if it does not exsist.
 	if (!td->home_timeline_gc)
-	{   
-		char *name_hint = g_strdup_printf( "Twitter_%s", ic->acc->user );
-		td->home_timeline_gc = gc = imcb_chat_new( ic, "home/timeline" );
-		imcb_chat_name_hint( gc, name_hint );
-		g_free( name_hint );
-		// Add the current user to the chat...
+		twitter_groupchat_init(ic);
+	
+	gc = td->home_timeline_gc;
+	if (!gc->joined)
 		imcb_chat_add_buddy( gc, ic->acc->user );
-	}
-	else
-	{   
-		gc = td->home_timeline_gc;
-	}
 
 	for ( l = list; l ; l = g_slist_next(l) )
 	{
 		status = l->data;
 		twitter_add_buddy(ic, status->user->screen_name, status->user->name);
 		
+		strip_html(status->text);
+		
 		// Say it!
 		if (g_strcasecmp(td->user, status->user->screen_name) == 0)
 			imcb_chat_log (gc, "Your Tweet: %s", status->text);
@@ -470,6 +513,7 @@ static void twitter_private_message_chat(struct im_connection *ic, GSList *list)
 		
 		status = l->data;
 		
+		strip_html( status->text );
 		if( mode_one )
 			text = g_strdup_printf( "\002<\002%s\002>\002 %s",
 			                        status->user->screen_name, status->text );
@@ -522,7 +566,7 @@ static void twitter_http_get_home_timeline(struct http_request *req)
 	{
 		// It didn't go well, output the error and return.
 		if (++td->http_fails >= 5)
-			imcb_error(ic, "Could not retrieve " TWITTER_HOME_TIMELINE_URL ". HTTP STATUS: %d", req->status_code);
+			imcb_error(ic, "Could not retrieve " TWITTER_HOME_TIMELINE_URL ": %s", twitter_parse_error(req));
 		
 		return;
 	}
@@ -571,15 +615,23 @@ static void twitter_http_get_statuses_friends(struct http_request *req)
 	td = ic->proto_data;
 	
 	// Check if the HTTP request went well.
-	if (req->status_code != 200) {
+	if (req->status_code == 401)
+	{
+		imcb_error( ic, "Authentication failure" );
+		imc_logout( ic, FALSE );
+		return;
+	} else if (req->status_code != 200) {
 		// It didn't go well, output the error and return.
-		if (++td->http_fails >= 5)
-			imcb_error(ic, "Could not retrieve " TWITTER_SHOW_FRIENDS_URL " HTTP STATUS: %d", req->status_code);
-		
+		imcb_error(ic, "Could not retrieve " TWITTER_SHOW_FRIENDS_URL ": %s", twitter_parse_error(req));
+		imc_logout( ic, TRUE );
 		return;
 	} else {
 		td->http_fails = 0;
 	}
+	
+	if( !td->home_timeline_gc &&
+	    g_strcasecmp( set_getstr( &ic->acc->set, "mode" ), "chat" ) == 0 )
+		twitter_groupchat_init( ic );
 
 	txl = g_new0(struct twitter_xml_list, 1);
 	txl->list = NULL;
@@ -601,8 +653,15 @@ static void twitter_http_get_statuses_friends(struct http_request *req)
 
 	// if the next_cursor is set to something bigger then 0 there are more friends to gather.
 	if (txl->next_cursor > 0)
+	{
 		twitter_get_statuses_friends(ic, txl->next_cursor);
-
+	}
+	else
+	{
+		td->flags |= TWITTER_HAVE_FRIENDS;
+		twitter_login_finish(ic);
+	}
+	
 	// Free the structure.
 	txl_free(txl);
 	g_free(txl);
@@ -611,23 +670,21 @@ static void twitter_http_get_statuses_friends(struct http_request *req)
 /**
  * Get the friends.
  */
-void twitter_get_statuses_friends(struct im_connection *ic, int next_cursor)
+void twitter_get_statuses_friends(struct im_connection *ic, gint64 next_cursor)
 {
-	struct twitter_data *td = ic->proto_data;
-
 	char* args[2];
 	args[0] = "cursor";
-	args[1] = g_strdup_printf ("%d", next_cursor);
+	args[1] = g_strdup_printf ("%lld", (long long) next_cursor);
 
-	twitter_http(TWITTER_SHOW_FRIENDS_URL, twitter_http_get_statuses_friends, ic, 0, td->user, td->pass, td->oauth_info, args, 2);
+	twitter_http(ic, TWITTER_SHOW_FRIENDS_URL, twitter_http_get_statuses_friends, ic, 0, args, 2);
 
 	g_free(args[1]);
 }
 
 /**
- * Callback after sending a new update to twitter.
+ * Callback to use after sending a post request to twitter.
  */
-static void twitter_http_post_status(struct http_request *req)
+static void twitter_http_post(struct http_request *req)
 {
 	struct im_connection *ic = req->data;
 
@@ -638,7 +695,7 @@ static void twitter_http_post_status(struct http_request *req)
 	// Check if the HTTP request went well.
 	if (req->status_code != 200) {
 		// It didn't go well, output the error and return.
-		imcb_error(ic, "Could not post message... HTTP STATUS: %d", req->status_code);
+		imcb_error(ic, "HTTP error: %s", twitter_parse_error(req));
 		return;
 	}
 }
@@ -648,12 +705,10 @@ static void twitter_http_post_status(struct http_request *req)
  */ 
 void twitter_post_status(struct im_connection *ic, char* msg)
 {
-	struct twitter_data *td = ic->proto_data;
-
 	char* args[2];
 	args[0] = "status";
 	args[1] = msg;
-	twitter_http(TWITTER_STATUS_UPDATE_URL, twitter_http_post_status, ic, 1, td->user, td->pass, td->oauth_info, args, 2);
+	twitter_http(ic, TWITTER_STATUS_UPDATE_URL, twitter_http_post, ic, 1, args, 2);
 //	g_free(args[1]);
 }
 
@@ -663,15 +718,21 @@ void twitter_post_status(struct im_connection *ic, char* msg)
  */
 void twitter_direct_messages_new(struct im_connection *ic, char *who, char *msg)
 {
-	struct twitter_data *td = ic->proto_data;
-
 	char* args[4];
 	args[0] = "screen_name";
 	args[1] = who;
 	args[2] = "text";
 	args[3] = msg;
 	// Use the same callback as for twitter_post_status, since it does basically the same.
-	twitter_http(TWITTER_DIRECT_MESSAGES_NEW_URL, twitter_http_post_status, ic, 1, td->user, td->pass, td->oauth_info, args, 4);
+	twitter_http(ic, TWITTER_DIRECT_MESSAGES_NEW_URL, twitter_http_post, ic, 1, args, 4);
 //	g_free(args[1]);
 //	g_free(args[3]);
 }
+
+void twitter_friendships_create_destroy(struct im_connection *ic, char *who, int create)
+{
+	char* args[2];
+	args[0] = "screen_name";
+	args[1] = who;
+	twitter_http(ic, create ? TWITTER_FRIENDSHIPS_CREATE_URL : TWITTER_FRIENDSHIPS_DESTROY_URL, twitter_http_post, ic, 1, args, 2);
+}
\ No newline at end of file
