@@ -129,16 +129,23 @@ static char *byahoo_strip( const char *in )
 static void byahoo_init( account_t *acc )
 {
 	set_add( &acc->set, "mail_notifications", "false", set_eval_bool, acc );
+	
+	acc->flags |= ACC_FLAG_AWAY_MESSAGE | ACC_FLAG_STATUS_MESSAGE;
 }
 
 static void byahoo_login( account_t *acc )
 {
 	struct im_connection *ic = imcb_new( acc );
 	struct byahoo_data *yd = ic->proto_data = g_new0( struct byahoo_data, 1 );
+	char *s;
 	
 	yd->logged_in = FALSE;
 	yd->current_status = YAHOO_STATUS_AVAILABLE;
 	
+	if( ( s = strchr( acc->user, '@' ) ) && g_strcasecmp( s, "@yahoo.com" ) == 0 )
+		imcb_error( ic, "Your Yahoo! username should just be a username. "
+		                "Do not include any @domain part." );
+	
 	imcb_log( ic, "Connecting" );
 	yd->y2_id = yahoo_init( acc->user, acc->pass );
 	yahoo_login( yd->y2_id, yd->current_status );
@@ -196,29 +203,12 @@ static int byahoo_send_typing( struct im_connection *ic, char *who, int typing )
 static void byahoo_set_away( struct im_connection *ic, char *state, char *msg )
 {
 	struct byahoo_data *yd = (struct byahoo_data *) ic->proto_data;
-	char *away;
 	
-	away = NULL;
-	
-	if( state && msg && g_strcasecmp( state, msg ) != 0 )
+	if( state && msg == NULL )
 	{
-		yd->current_status = YAHOO_STATUS_CUSTOM;
-		away = "";
-	}
-	else if( state )
-	{
-		/* Set msg to NULL since (if it isn't NULL already) it's equal
-		   to state. msg must be empty if we want to use an existing
-		   away state. */
-		msg = NULL;
-		
-		away = "";
-		if( g_strcasecmp( state, "Available" ) == 0 )
-		{
-			yd->current_status = YAHOO_STATUS_AVAILABLE;
-			away = NULL;
-		}
-		else if( g_strcasecmp( state, "Be Right Back" ) == 0 )
+		/* Use these states only if msg doesn't contain additional
+		   info since away messages are only supported with CUSTOM. */
+		if( g_strcasecmp( state, "Be Right Back" ) == 0 )
 			yd->current_status = YAHOO_STATUS_BRB;
 		else if( g_strcasecmp( state, "Busy" ) == 0 )
 			yd->current_status = YAHOO_STATUS_BUSY;
@@ -238,17 +228,15 @@ static void byahoo_set_away( struct im_connection *ic, char *state, char *msg )
 			yd->current_status = YAHOO_STATUS_STEPPEDOUT;
 		else if( g_strcasecmp( state, "Invisible" ) == 0 )
 			yd->current_status = YAHOO_STATUS_INVISIBLE;
-		else if( g_strcasecmp( state, GAIM_AWAY_CUSTOM ) == 0 )
-		{
-			yd->current_status = YAHOO_STATUS_AVAILABLE;
-			
-			away = NULL;
-		}
+		else
+			yd->current_status = YAHOO_STATUS_CUSTOM;
 	}
+	else if( msg )
+		yd->current_status = YAHOO_STATUS_CUSTOM;
 	else
 		yd->current_status = YAHOO_STATUS_AVAILABLE;
 	
-	yahoo_set_away( yd->y2_id, yd->current_status, msg, away != NULL ? 2 : 0 );
+	yahoo_set_away( yd->y2_id, yd->current_status, msg, state ? 2 : 0 );
 }
 
 static GList *byahoo_away_states( struct im_connection *ic )
@@ -257,7 +245,6 @@ static GList *byahoo_away_states( struct im_connection *ic )
 
 	if( m == NULL )
 	{
-		m = g_list_append( m, "Available" );
 		m = g_list_append( m, "Be Right Back" );
 		m = g_list_append( m, "Busy" );
 		m = g_list_append( m, "Not At Home" );
@@ -268,7 +255,6 @@ static GList *byahoo_away_states( struct im_connection *ic )
 		m = g_list_append( m, "Out To Lunch" );
 		m = g_list_append( m, "Stepped Out" );
 		m = g_list_append( m, "Invisible" );
-		m = g_list_append( m, GAIM_AWAY_CUSTOM );
 	}
 	
 	return m;
@@ -846,6 +832,10 @@ void ext_yahoo_got_conf_invite( int id, const char *ignored,
 	char txt[1024];
 	YList *m;
 	
+	if( g_strcasecmp( who, ic->acc->user ) == 0 )
+		/* WTF, Yahoo! seems to echo these now? */
+		return;
+	
 	inv = g_malloc( sizeof( struct byahoo_conf_invitation ) );
 	memset( inv, 0, sizeof( struct byahoo_conf_invitation ) );
 	inv->name = g_strdup( room );
